@@ -103,6 +103,9 @@ class DescriptionItem:
     def get_tags(self, parent_tag: etree.Element) -> None:
         raise NotImplementedError()
 
+    def get_translated_tag(self, lang: Optional[str]) -> etree.Element:
+        raise NotImplementedError()
+
 
 class DescriptionParagraph(DescriptionItem):
     def __init__(self) -> None:
@@ -118,6 +121,15 @@ class DescriptionParagraph(DescriptionItem):
     def get_tags(self, parent_tag: etree.Element) -> None:
         self.content.write_tags(parent_tag, "p")
 
+    def get_translated_tag(self, lang: Optional[str]) -> etree.Element:
+        "Get the translated tag"
+        paragraph_tag = etree.Element("p")
+        if lang is None:
+            paragraph_tag.text = self.content.get_default_text()
+        else:
+            paragraph_tag.text = self.content.get_translated_text(lang)
+        return paragraph_tag
+
 
 class DescriptionList(DescriptionItem):
     def __init__(self, list_type: str) -> None:
@@ -136,7 +148,14 @@ class DescriptionList(DescriptionItem):
         self.content.load_tag(tag_list)
 
     def get_tags(self, parent_tag: etree.Element) -> None:
-        self.content.write_all_tag(parent_tag, self._list_type)
+        list_tag = etree.SubElement(parent_tag, self._list_type)
+        self.content.write_all_tag(list_tag, "li")
+
+    def get_translated_tag(self, lang: Optional[str]) -> etree.Element:
+        "Get the translated tag"
+        list_tag = etree.Element(self._list_type)
+        self.content.write_all_tag(list_tag, "li")
+        return list_tag
 
 
 class Description:
@@ -162,6 +181,7 @@ class Description:
                     paragraph_item = DescriptionParagraph()
                     paragraph_item.load_tags(paragraph_list)
                     self.items.append(paragraph_item)
+                    paragraph_list.clear()
 
                 list_item = DescriptionList(i.tag)
                 list_item.load_tags(i)
@@ -172,11 +192,26 @@ class Description:
             paragraph_item.load_tags(paragraph_list)
             self.items.append(paragraph_item)
 
-    def get_tags(self, parent_tag: etree.Element):
+    def get_tags(self, parent_tag: etree.Element) -> None:
         description_tag = etree.SubElement(parent_tag, "description")
         for i in self.items:
             i.get_tags(description_tag)
 
+    def to_html(self, lang: Optional[str]) -> str:
+        "Get the HTML code of the description in the given language"
+        description_tag = etree.Element("description")
+
+        for i in self.items:
+            description_tag.append(i.get_translated_tag(lang))
+
+        text = etree.tostring(description_tag).decode("utf-8")
+        text = text.replace("<description>", "")
+        text = text.replace("</description>", "")
+        text = text.replace("<description/>", "")
+        text = text.replace("\n", "")
+
+        return text.strip()
+
 
 class Release:
     def __init__(self) -> None:
@@ -186,6 +221,9 @@ class Release:
         self.date: Optional[datetime.date]
         "The date"
 
+        self.description = Description()
+        "The description"
+
     def load_tag(self, tag: etree.Element):
         "Loads a release tag"
 
@@ -201,6 +239,48 @@ class Release:
         except Exception:
             pass
 
+        description_tag = tag.find("description")
+        if description_tag is not None:
+            self.description.load_tags(description_tag)
+
+
+class Image:
+    def __init__(self) -> None:
+        self.url: str
+        "The image URL"
+
+        self.type: str
+        "The image type"
+
+    def load_tag(self, tag: etree.Element):
+        "Loads a image tag"
+        self.url = tag.text
+        self.type = tag.get("type")
+
+
+class Screenshot:
+    def __init__(self) -> None:
+        self.source_image: Image
+        "The source image"
+
+        self.thumbnail_images: list[Image] = []
+        "the list with thumbnail images"
+
+        self.caption: TranslateableTag = TranslateableTag()
+        "The caption"
+
+    def load_tag(self, tag: etree.Element):
+        "Load a screenshot tag"
+        for i in tag.findall("image"):
+            img = Image()
+            img.load_tag(i)
+            if img.type == "source":
+                self.source_image = img
+            elif img.type == "thumbnail":
+                self.thumbnail_images.append(img)
+
+        self.caption.load_tags(tag.findall("caption"))
+
 
 class AppstreamComponent:
     def __init__(self) -> None:
@@ -240,12 +320,12 @@ class AppstreamComponent:
         self.provides: dict[str, str] = {}
         "The provides. The content of the depracted mimetype tag goes intp provides['mimetype']"
 
-        for i in PROVIDES_TYPES:
-            self.provides[i] = []
-
         self.releases: list[Release] = []
         "The releases"
 
+        self.screenshots: list[Screenshot] = []
+        "The screenshots"
+
         self.project_group: Optional[str] = None
         "The project group"
 
@@ -258,6 +338,9 @@ class AppstreamComponent:
         self.keywords: TranslateableList = TranslateableList()
         "The Keywords"
 
+        self.controls: dict[str, Optional[str]] = {}
+        "The Controls"
+
         self.kudos: list[str] = []
         "The Kudos"
 
@@ -267,6 +350,8 @@ class AppstreamComponent:
         self.extends: list[str] = []
         "The extends tag for addons"
 
+        self.clear()
+
     def clear(self) -> None:
         """Resets the Component"""
         self.id = ""
@@ -282,10 +367,12 @@ class AppstreamComponent:
         self.oars.clear()
         self.provides.clear()
         self.releases.clear()
+        self.screenshots.clear
         self.project_group = None
         self.translation.clear()
         self.languages.clear()
         self.keywords.clear()
+        self.controls.clear()
         self.kudos.clear()
         self.update_contact = None
         self.extends.clear()
@@ -293,11 +380,22 @@ class AppstreamComponent:
         for i in PROVIDES_TYPES:
             self.provides[i] = []
 
+        for i in CONTROL_TYPES:
+            self.controls[i] = None
+
     def get_aviable_languages(self) -> list[str]:
         "Returns a list with all aviable languages of the Component"
         lang_list = self.name.get_aviable_languages() + self.summary.get_aviable_languages() + self.developer_name.get_aviable_languages()
         return list(set(lang_list))
 
+    def _parse_relation_tag(self, tag: etree.Element) -> None:
+        "Parses a relation tag"
+        relation = tag.tag
+
+        for i in tag.findall("control"):
+            if i.text in CONTROL_TYPES:
+                self.controls[i.text] = relation
+
     def parse_component_tag(self, tag: etree._ElementTree) -> None:
         self.id = tag.find("id").text
 
@@ -363,6 +461,13 @@ class AppstreamComponent:
                 release_object.load_tag(i)
                 self.releases.append(release_object)
 
+        screenshots_tag = tag.find("screenshots")
+        if screenshots_tag is not None:
+            for i in screenshots_tag.findall("screenshot"):
+                screenshot = Screenshot()
+                screenshot.load_tag(i)
+                self.screenshots.append(screenshot)
+
         project_group_tag = tag.find("project_group")
         if project_group_tag is not None:
             self.project_group = project_group_tag.text
@@ -384,6 +489,18 @@ class AppstreamComponent:
         for i in tag.findall("keywords"):
             self.keywords.load_tag(i)
 
+        supports_tag = tag.find("supports")
+        if supports_tag is not None:
+            self._parse_relation_tag(supports_tag)
+
+        recommends_tag = tag.find("recommends")
+        if recommends_tag is not None:
+            self._parse_relation_tag(recommends_tag)
+
+        requires_tag = tag.find("requires")
+        if requires_tag is not None:
+            self._parse_relation_tag(requires_tag)
+
         kudos_tag = tag.find("kudos")
         if kudos_tag is not None:
             for i in kudos_tag.findall("kudo"):
@@ -401,6 +518,17 @@ class AppstreamComponent:
         root = etree.parse(path)
         self.parse_component_tag(root)
 
+    def _get_relation_tag(self, parent_tag: etree.Element, relation: str) -> None:
+        relation_tag = etree.SubElement(parent_tag, relation)
+
+        for key, value in self.controls:
+            if key in CONTROL_TYPES and value == relation:
+                control_tag = etree.SubElement("control")
+                control_tag.text = key
+
+        if len(relation_tag.getchildren()) == 0:
+            parent_tag.remove(relation_tag)
+
     def get_component_tag(self) -> etree.Element:
         tag = etree.Element("component")
         tag.set("type", self.type)
@@ -469,6 +597,10 @@ class AppstreamComponent:
                 single_language_tag.set("percentage", str(value))
                 single_language_tag.text = key
 
+        self._get_relation_tag(tag, "supports")
+        self._get_relation_tag(tag, "recommends")
+        self._get_relation_tag(tag, "supports")
+
         if len(self.kudos) > 0:
             kudos_tag = etree.SubElement(tag, "kudos")
             for i in self.kudos:
